pub struct CompositeObserver { /* private fields */ }Expand description
An observer that fans out callbacks to a list of observers.
Implementations
Sourceimpl CompositeObserver
impl CompositeObserver
Sourcepub fn new(observers: Vec<Arc<dyn IngestionObserver>>) -> Self
pub fn new(observers: Vec<Arc<dyn IngestionObserver>>) -> Self
Create a new composite observer from a list of observers.