pub fn parse_partition_segment(component: &str) -> Option<PartitionSegment>Expand description
Parse a single path component as key=value.
Returns None if there is no =, either side is empty, or the string is malformed.
pub fn parse_partition_segment(component: &str) -> Option<PartitionSegment>Parse a single path component as key=value.
Returns None if there is no =, either side is empty, or the string is malformed.