pub struct IngestionRequest {
pub path: PathBuf,
pub schema: Schema,
pub options: IngestionOptions,
}Expand description
Convenience helper for callers that want an owned request object.
This can be useful if you want to enqueue ingestion work in a job system.
Fields
path: PathBufPath to the input file.
schema: SchemaSchema to validate/parse values into.
options: IngestionOptionsOptions controlling ingestion.
Implementations
Sourceimpl IngestionRequest
impl IngestionRequest
Sourcepub fn run(&self) -> IngestionResult<DataSet>
pub fn run(&self) -> IngestionResult<DataSet>
Execute the request by calling ingest_from_path.