pub fn validate_watermark_config(
schema: &Schema,
options: &IngestionOptions,
) -> IngestionResult<()>Expand description
Ensure watermark options are consistent with schema and with each other.
pub fn validate_watermark_config(
schema: &Schema,
options: &IngestionOptions,
) -> IngestionResult<()>Ensure watermark options are consistent with schema and with each other.