pub struct DataSet {
pub schema: Schema,
pub rows: Vec<Vec<Value>>,
}Expand description
In-memory tabular dataset.
Rows are stored as Vec<Vec<Value>> in the same order as the Schema fields.
Fields
schema: SchemaSchema describing row shape.
rows: Vec<Vec<Value>>Row-major value storage.
Implementations
Sourceimpl DataSet
impl DataSet
Sourcepub fn new(schema: Schema, rows: Vec<Vec<Value>>) -> Self
pub fn new(schema: Schema, rows: Vec<Vec<Value>>) -> Self
Create a dataset from schema and rows.
Sourcepub fn filter_rows<F>(&self, predicate: F) -> Self
pub fn filter_rows<F>(&self, predicate: F) -> Self
Create a new dataset containing only rows that match predicate.
The returned dataset preserves the original schema.
Sourcepub fn map_rows<F>(&self, mapper: F) -> Self
pub fn map_rows<F>(&self, mapper: F) -> Self
Create a new dataset by applying mapper to every row.
The returned dataset preserves the original schema.
Panics
Panics if mapper returns a row with a different length than the schema field count.
Sourcepub fn reduce_rows<A, F>(&self, init: A, reducer: F) -> A
pub fn reduce_rows<A, F>(&self, init: A, reducer: F) -> A
Reduce (fold) all rows into an accumulator value.
This is similar to Iterator::fold, but provides each row as &[Value].